// Copyright 2009 Christopher Smith
// 
// This file is part of smithers.files.
// 
// smithers.files is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the Free
// Software Foundation, either version 3 of the License, or (at your option)
// any later version.
// 
// smithers.files is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
// or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
// 
// You should have received a copy of the GNU General Public License along with
// smithers.files. If not, see <http://www.gnu.org/licenses/>.

package smithers.files;

import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;

/**
 * Writes data to a CSV file.
 */
public class CSVWriter {
    
    private BufferedWriter out;
    private StringBuilder currentRow = new StringBuilder();
    
    /**
     * Creates a {@code CSVWriter} which writes to the specified file.
     * 
     * @param fileName the name of the file to write to
     * @throws IOException if the file cannot be opened for any reason
     */
    public CSVWriter(String fileName) throws IOException {
        out = new BufferedWriter(new FileWriter(fileName));
    }
    
    /**
     * Adds a cell to the current row.
     * 
     * @param contents the contents of the cell
     */
    public void addCell(String contents) {
        if (currentRow.length() > 0) currentRow.append(',');
        
        if (contents.contains(",") || contents.contains("\"") || contents.contains("\n"))
            currentRow.append('\"').append(contents.replace("\"", "\"\"")).append('\"');
        else
            currentRow.append(contents);
    }
    
    /**
     * Outputs the current row.
     * 
     * @throws IOException if an I/O error occurs
     */
    public void writeRow() throws IOException {
        out.write(currentRow.toString());
        out.newLine();
        currentRow.setLength(0);
    }
    
    /**
     * Flushes the output stream.
     * 
     * @throws IOException if an I/O error occurs
     */
    public void flush() throws IOException {
        out.flush();
    }
    
}
