// Copyright 2009, 2010, 2012 Christopher Smith
// 
// This file is part of smithers.util.
// 
// smithers.util is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the Free
// Software Foundation, either version 3 of the License, or (at your option)
// any later version.
// 
// smithers.util is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
// 
// You should have received a copy of the GNU General Public License along with
// smithers.util. If not, see <http://www.gnu.org/licenses/>.

package smithers.util;

import java.awt.Component;
import java.awt.EventQueue;
import java.awt.Frame;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

/**
 * Convenience class to launch AWT or Swing components from the AWT event
 * dispatching thread. When this class launches a component, it creates a new
 * {@code Frame} with the specified size and dimensions, adds a {@code
 * WindowListener} which disposes the window when closed, ands adds and gives
 * focus to the component.
 */
public class Launcher {
    
    private Launcher() {}
    
    /**
     * Adds an event to launch a new window containing the specified component.
     * 
     * @param c      the {@code Component} to launch
     * @param title  the title to give the frame
     * @param width  the width of the frame
     * @param height the height of the frame
     */
    public static void launch(final Component c, final String title, final int width, final int height) {
        EventQueue.invokeLater(new Runnable() {
            public void run() {
                Frame frame = new Frame(title);
                frame.addWindowListener(new WindowAdapter() {
                    public void windowClosing(WindowEvent we) {
                        we.getWindow().dispose();
                    }
                });
                frame.setSize(width, height);
                frame.add(c);
                c.requestFocusInWindow();
                frame.setVisible(true);
            }
        });
    }
    
}
